@@ -1,4 +1,4 @@
-import django
+from django import VERSION as DJANGO_VERSION
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 
@@ -19,5 +19,5 @@ for variable, instance_type in SETTINGS_TYPES.items():
             "Setting %s is not of type" % variable, instance_type
         )
 
-if django.VERSION < (3, 2):
+if DJANGO_VERSION < (3, 2):
     default_app_config = "captcha.apps.CaptchaConfig"
